use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
Alders
Alders'
Arthur
Axel
Ben
Bullock
Carwyn
DOCTYPE
Dagfinn
David
Elliott
Etheridge
Fitz
Forsyth
Golden
Graham
HTML
Ilmari
Jubenville
Karen
Knop
Mannsåker
Mark
Olaf
Raybec
Restrict
Schmidt
TerMarsch
XSS
benkasminbullock
bolded
calyx238
dagolden
ether
fREW
fitz
frioux
graham
haarg
href
img
ioncache
lib
mark
olaf
param
params
perlpong
sam
schemas
skaufman
src
whitelisted
whitelisting
